+++
title = "About"
description = "Initial project description"
date = "2019-08-07"
author = "Christian Decker"
sec = 1
+++

One-Day-Only or OneDly projects help to acquire a new skill or to complete a task within a short timeframe. It limits the available time and combines it with defined objectives. This situation forces you to focus on the relevant elements in order to successfully complete a task or project. Please note, the idea is not to pack as much work as you can do within a workday. At the end you will find answers for the following questions 

* What were the relevant elements for success?
* How good are you in estimating your work effort?
* What were road blocks or even showstoppers you haven't forseen even in a short-term project horizon?
* What are typical reoccuring interuptions and distractions during your work?
* What is your personal pace when working intensly on a task or project?


This will certainly generate some personal insights and improve your activities in future projects. 

### Structuring OneDly Projects

A single page stores an entire OneDly project documentation. We recommend the following  concise structure.

* About: Some background / intro information motivating the project
* Project Definition
    * Goal
    * Approach and Objectives
* Sections
* ...
* Summary and Conclusions
* Next steps

### Example

Raspi mini computers are embedded computers running linux and provide a desktop alike programming experiences. They are available at low cost. Being able to develop software for these systems is a valuable contribution to one's CV.

This OneDly project experiements with the Raspi setup, development and deployment of some example software.




